@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020 Jakub Kruszona-Zawadzki, Core Technology Sp. z o.o.
+ * Copyright (C) 2021 Jakub Kruszona-Zawadzki, Core Technology Sp. z o.o.
  * 
  * This file is part of MooseFS.
  * 
@@ -76,8 +76,6 @@
 
 #define MFS_MAX_FILE_SIZE (((uint64_t)(MFSCHUNKSIZE))<<31)
 
-#define MFS_INODE_REUSE_DELAY 86400
-
 #define TRASH_BUCKETS 4096
 #define SUSTAINED_BUCKETS 256
 
@@ -1170,7 +1168,7 @@
 // 0x01A5
 #define MATOCL_FUSE_UNLINK (PROTO_BASE+421)
 // msgid:32 status:8
-// since 3.0.107 (after succesful remove):
+// since 3.0.107 (after successful remove):
 // msgid:32 inode:32
 
 // 0x01A6
@@ -1181,7 +1179,7 @@
 // 0x01A7
 #define MATOCL_FUSE_RMDIR (PROTO_BASE+423)
 // msgid:32 status:8
-// since 3.0.107 (after succesful remove):
+// since 3.0.107 (after successful remove):
 // msgid:32 inode:32
 
 // 0x01A8
